import argparse
import active_sessions

# Create an argument parser.
parser = argparse.ArgumentParser('active-sessions')


def main(args=None):
    """Main entry point for your project.
    """


if __name__ == '__main__':
    main(['-h'])
